NEWS update.
[paraslash.git] / client.h
index 06eeda387932765321c92093ee451aa590b25ae0..3b115fa307b4a93e4b61e5010edf40050945ace2 100644 (file)
--- a/client.h
+++ b/client.h
@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1997-2007 Andre Noll <maan@systemlinux.org>
+ * Copyright (C) 1997-2008 Andre Noll <maan@systemlinux.org>
  *
  * Licensed under the GPL v2. For licencing details see COPYING.
  */
@@ -58,7 +58,7 @@ struct private_client_data {
        /** the client task structure */
        struct task task;
        /** non-zero if task is unregistered */
-       int eof;
+       int error;
        /** the buffer used for handshake and receiving */
        char buf[CLIENT_BUFSIZE];
        /** number of bytes loaded in \p buf */
@@ -73,11 +73,9 @@ struct private_client_data {
        char *inbuf;
        /** number of bytes loaded in \p inbuf */
        size_t *in_loaded;
-       /** non-zero if input task encountered an eof or an errro condition */
-       int *in_eof;
+       /** Non-zero if input task encountered an eof or an error condition. */
+       int *in_error;
 };
 
 void client_close(struct private_client_data *pcd);
 int client_open(int argc, char *argv[], struct private_client_data **pcd_ptr);
-void client_pre_select(struct sched *s, struct task *t);
-void client_post_select(struct sched *s, struct task *t);